@@ -1,4 +1,4 @@
-from typing import Union
+from typing import Union, List
 from nltk.stem import PorterStemmer
 import numpy as np
 import pandas as pd
@@ -89,12 +89,12 @@ def preprocess(sentence: str, remove_punct: bool, remove_stop_words: bool, stemm
 class sentence_tranformer_checker():
     def __init__(
         self, 
-        targets: Union[list[str], pd.DataFrame], 
-        target_group: Union[list[str], pd.DataFrame]=None,
+        targets: Union[List[str], pd.DataFrame], 
+        target_group: Union[List[str], pd.DataFrame]=None,
         target_col: str=None, 
         model: SentenceTransformer=None, 
         lang: str='en', 
-        only_include: list[str]=None,
+        only_include: List[str]=None,
         encode_batch = 32,
         encode_target = True,
         remove_punct: bool=True, 
@@ -196,7 +196,7 @@ class sentence_tranformer_checker():
 
     def match(
         self, 
-        source: Union[list[str], pd.DataFrame], 
+        source: Union[List[str], pd.DataFrame], 
         source_col: str=None, 
         topn: int=1, 
         return_match_idx: bool=False, 
